CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
52 lines
1.7 KiB
Plaintext
52 lines
1.7 KiB
Plaintext
// RUN: %clang_cc1 -std=gnu++11 -triple nvptx64-unknown-unknown -fsyntax-only -verify %s
|
|
// RUN: %clang_cc1 -std=gnu++11 -triple nvptx64-unknown-unknown -fcuda-is-device -fsyntax-only -verify %s
|
|
|
|
struct CopyableH {
|
|
const CopyableH& operator=(const CopyableH& x) { return *this; }
|
|
};
|
|
struct CopyableD {
|
|
__attribute__((device)) const CopyableD& operator=(const CopyableD x) { return *this; }
|
|
};
|
|
|
|
struct SimpleH {
|
|
CopyableH b;
|
|
};
|
|
// expected-note@-3 2 {{candidate function (the implicit copy assignment operator) not viable: call to __host__ function from __device__ function}}
|
|
// expected-note@-4 2 {{candidate function (the implicit move assignment operator) not viable: call to __host__ function from __device__ function}}
|
|
|
|
struct SimpleD {
|
|
CopyableD b;
|
|
};
|
|
// expected-note@-3 2 {{candidate function (the implicit copy assignment operator) not viable: call to __device__ function from __host__ function}}
|
|
// expected-note@-4 2 {{candidate function (the implicit move assignment operator) not viable: call to __device__ function from __host__ function}}
|
|
|
|
void foo1hh() {
|
|
SimpleH a, b;
|
|
a = b;
|
|
}
|
|
__attribute__((device)) void foo1hd() {
|
|
SimpleH a, b;
|
|
a = b; // expected-error {{no viable overloaded}}
|
|
}
|
|
void foo1dh() {
|
|
SimpleD a, b;
|
|
a = b; // expected-error {{no viable overloaded}}
|
|
}
|
|
__attribute__((device)) void foo1dd() {
|
|
SimpleD a, b;
|
|
a = b;
|
|
}
|
|
|
|
void foo2hh(SimpleH &a, SimpleH &b) {
|
|
a = b;
|
|
}
|
|
__attribute__((device)) void foo2hd(SimpleH &a, SimpleH &b) {
|
|
a = b; // expected-error {{no viable overloaded}}
|
|
}
|
|
void foo2dh(SimpleD &a, SimpleD &b) {
|
|
a = b; // expected-error {{no viable overloaded}}
|
|
}
|
|
__attribute__((device)) void foo2dd(SimpleD &a, SimpleD &b) {
|
|
a = b;
|
|
}
|